Materrine™ is a powerful, readable, relative database which allows you to store
your data anywhere, anyplace. And also allows you to store tags related with data
into the database. The powerful built-in searching function will search ALL the
data related to your targets. With useful tools to help you to manage all you data,
everyone is able to use it. Storing data by just one function. Use materrine.help()
for more info. Created by Marcy Mill. 
